@@ -3,11 +3,13 @@ class User:
     def __init__(self, user, uid):
         self.user = user
         self.uid = uid
+        self.friend_id = None
         #super().__init__()
 
     def __init__(self):
         self.user = None
         self.uid = None
+        self.friend_id = None
 
     def _getUser_(self):
         return self.user
@@ -42,4 +44,10 @@ class User:
     def _isNone_(self):
         if self.user is None and self.uid is None:
             return True
-        return False                               
\ No newline at end of file
+        return False
+        
+    def get_friend_id(self):
+        return self.friend_id
+        
+    def set_friend_id(self, id):
+        self.friend_id = id
\ No newline at end of file
